@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -52,7 +52,7 @@ SelectHeadersDialog::SelectHeadersDialog(QWidget *parent)
 
     QVBoxLayout *lay = new QVBoxLayout;
     lay->setObjectName(QStringLiteral("widgetlayout"));
-    lay->setMargin(0);
+    lay->setContentsMargins(0, 0, 0, 0);
     mainLayout->addLayout(lay);
     mListWidget = new SelectHeadersWidget(this);
     mListWidget->setObjectName(QStringLiteral("listwidget"));
